
# Introduction
CeleScope is a collection of bioinfomatics analysis pipelines to process single cell sequencing data generated with Singleron products. These pipelines take paired-end FASTQ files as input and generate output files which can be used for downstream data analysis as well as a summary of QC criteria.

# Documentation

[User guide](./doc/user_guide.md)

# Support
Please use the issue tracker for questions and malfunctions.

# About
CeleScope is currently developed by Singleron Biotechnologies.

[www.singleron.bio](https://www.singleron.bio)



